const test = require("tape");
const helpers = require("./helpers");

const tt = require("../src/tokenTypes");

test("compiles a simple template", t => {
  t.plan(1);
  const result = helpers.compile(`
    (div :class "foobar"
      (p :class "bazquux" "Lorem ipsum dolor sit amet."))
  `);
  t.deepEqual(
    result.replace(/\n/g, "").replace(/  +/g, ""),
    '<div class="foobar"><p class="bazquux">Lorem ipsum dolor sit amet.</p></div>'
  );
});

test("renders variables according to passed-in context", t => {
  t.plan(1);
  const result = helpers.compile(
    `
      (div :class classOne
        (p :class classTwo bodyText))
    `,
    {
      classOne: "foobar",
      classTwo: "bazquux",
      bodyText: "Lorem ipsum dolor sit amet."
    }
  );
  t.deepEqual(
    result.replace(/\n/g, "").replace(/  +/g, ""),
    '<div class="foobar"><p class="bazquux">Lorem ipsum dolor sit amet.</p></div>'
  );
});

test("self closing tags are respected", function(t) {
  t.plan(1);
  const result = helpers.compile(`
    (meta :charset "UTF-8")
    (img :src "test.png")
  `);
  t.deepEqual(
    result.replace(/\n/g, "").replace(/  +/g, ""),
    '<meta charset="UTF-8"><img src="test.png">'
  );
});
